package main

import "fmt"

type commandLineOptions struct {
	Path         string `short:"p" long:"path" description:"define the path where the specifications are located" default:"."`
	DateFormat   string `short:"f" long:"date-format" description:"date format" default:"2006-01-02"`
	Requirements struct {
		Print struct {
			Columns []string `short:"c" long:"column" description:"defines the columns used"`
		} `command:"print"`
		Add struct {
			ID string `long:"id" required:"true" description:"new requirement id"`
		} `command:"add"`
	} `command:"requirements"`
	Tasks struct {
		Print struct {
		} `command:"print"`
	} `command:"tasks"`
	Items struct {
		Print struct {
		} `command:"print"`
	} `command:"items"`
	Overview struct {
		Print struct {
			Columns      []string `short:"c" long:"column" description:"defines the columns used"`
			TemplatePath string   `short:"t" long:"template" description:"file name of the template of the overview page"`
			Output       string   `short:"o" long:"output" description:"redirect output to a file"`
			Format       string   `short:"f" long:"format" description:"the desired output format (pdf, md)"`
		} `command:"print"`
	} `command:"overview"`
	Version struct {
	} `command:"version"`
}

func executeCommand() {

	activeCommand, arguments, config := NewConfiguration()

	version = "development"
	build = "1.1.1"
	//
	switch activeCommand.Name {

	case "version":
		fmt.Println("Version " + version + " (" + build + ")")
	case "overview":
		subcommand := activeCommand.Active
		switch subcommand.Name {
		case "print":
			err := PrintOverview(config, arguments)
			if err != nil {
				printErrorAndExit(2, err.Error())
			}
		}

	case "requirements":
		subcommand := activeCommand.Active
		switch subcommand.Name {
		case "add":
			err := addRequirement(config, arguments)
			if err != nil {
				printErrorAndExit(2, err.Error())
			}
		case "print":
			err := printRequirements(config)
			if err != nil {
				printErrorAndExit(2, err.Error())
			}
		}

	case "tasks":
		subcommand := activeCommand.Active
		switch subcommand.Name {
		case "print":
			err := printTaskTable(config)
			if err != nil {
				printErrorAndExit(2, err.Error())
			}
		}

	case "items":
		subcommand := activeCommand.Active
		switch subcommand.Name {
		case "print":
			err := printItemTable(config)
			if err != nil {
				printErrorAndExit(2, err.Error())
			}
		}

	}
}
