package main

import (
	"errors"
	"io/ioutil"
	"os"
	"path"
	"path/filepath"
	"strings"

	"gopkg.in/yaml.v3"
)

//
func GetPageData(directory string) (error, map[string]requirement) {

	cleanedDirectory := path.Clean(directory)

	pageMap := make(map[string]requirement)

	//pageMap := []requirement{}

	err := filepath.Walk(cleanedDirectory,
		func(current string, info os.FileInfo, err error) error {
			if err != nil {
				return err
			}

			cleanedPath := path.Clean(current)

			if info.IsDir() {
				return nil
			}

			ext := filepath.Ext(cleanedPath)
			if ext != ".md" {
				return nil
			}

			content, err := ioutil.ReadFile(cleanedPath)

			if err != nil {
				return err
			}

			err, p := importData(content)

			if err != nil {
				printError("does not contain a valid yaml definition", cleanedPath)
				return nil
			}

			bd := []byte(cleanedDirectory)
			bp := []byte(cleanedPath)
			bs := string(bp[len(bd):len(bp)])

			p.File = "." + bs
			p.Absolute = cleanedPath
			p.ToDos = findTask(content)
			//requirement[cleanedPath] = requirement

			k := cleanedPath

			pageMap[k] = p

			return nil
		})

	return err, pageMap
}

func importData(content []byte) (error, requirement) {

	data := requirement{}

	s := string(content)
	a := strings.Index(s, "\n---")
	if a == -1 {
		return errors.New("the file does not contain a definition block"), requirement{}
	}
	s = s[a+4 : len(s)-1]
	b := strings.Index(s, "\n...")

	if b == -1 {
		b = strings.Index(s, "\n---")
	}

	if b > -1 {
		s = s[0:b]
	}

	err := yaml.Unmarshal([]byte(s), &data)

	if err != nil {
		return err, requirement{}
	}

	return nil, data
}
